==> arq-2.8.7-sources.jar: arq/cmdline/CmdUpdate.java <==
/*
 * (c) Copyright 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 * [See end of file]
 */

package arq.cmdline;

import com.hp.hpl.jena.rdf.model.ModelFactory ;
import com.hp.hpl.jena.update.GraphStore ;

public abstract class CmdUpdate extends CmdARQ
{
    protected ModGraphStore modGraphStore = new ModGraphStore() ;
    
    protected CmdUpdate(String[] argv)
    {
        super(argv) ;
        addModule(modGraphStore) ;
    }
    
    @Override
    protected final void exec()
    {
        GraphStore graphStore = modGraphStore.getGraphStore() ;
        if ( graphStore.getDefaultGraph() == null )
            graphStore.setDefaultGraph(ModelFactory.createDefaultModel().getGraph()); 
        
        execUpdate(graphStore) ;
    }

    protected abstract void execUpdate(GraphStore graphStore) ;
}

/*
 * (c) Copyright 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

==> arq-2.8.8-sources.jar: arq/cmdline/CmdUpdate.java <==
/*
 * (c) Copyright 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 * [See end of file]
 */

package arq.cmdline;

import com.hp.hpl.jena.query.Syntax ;
import com.hp.hpl.jena.rdf.model.ModelFactory ;
import com.hp.hpl.jena.update.GraphStore ;

public abstract class CmdUpdate extends CmdARQ
{
    protected ModGraphStore modGraphStore = new ModGraphStore() ;
    protected Syntax updateSyntax = Syntax.defaultUpdateSyntax ;

    protected CmdUpdate(String[] argv)
    {
        super(argv) ;
        modGraphStore = setModGraphStore() ;
        addModule(modGraphStore) ;
        
    }
    
    protected ModGraphStore setModGraphStore()
    {
        return new ModGraphStore() ;
    }
    

    @Override
    protected void processModulesAndArgs()
    {
        super.processModulesAndArgs() ;
        if ( super.cmdStrictMode )
            updateSyntax = Syntax.syntaxSPARQL_11 ;
    }
    
    
    @Override
    protected final void exec()
    {
        GraphStore graphStore = modGraphStore.getGraphStore() ;
        if ( graphStore.getDefaultGraph() == null )
            graphStore.setDefaultGraph(ModelFactory.createDefaultModel().getGraph()); 
        
        execUpdate(graphStore) ;
    }

    protected abstract void execUpdate(GraphStore graphStore) ;
}

/*
 * (c) Copyright 2008, 2009 Hewlett-Packard Development Company, LP
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
